# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"grid_search": "00_core.ipynb",
         "test_grid_search_first_entries": "00_core.ipynb",
         "test_grid_search_default_n": "00_core.ipynb",
         "test_grid_search_default_load_test": "00_core.ipynb",
         "random_search": "00_core.ipynb",
         "test_random_search_with_seed": "00_core.ipynb",
         "test_random_search_default_n": "00_core.ipynb",
         "test_random_search_default_load_test": "00_core.ipynb",
         "latin_hyper_cube": "00_core.ipynb",
         "test_latin_hyper_cube_with_seed": "00_core.ipynb",
         "test_latin_hyper_cube_default_n": "00_core.ipynb",
         "test_latin_hyper_cube_default_load_test": "00_core.ipynb",
         "jittered_sampling": "00_core.ipynb",
         "test_jittered_sampling_with_seed": "00_core.ipynb",
         "test_jittered_sampling_default_n": "00_core.ipynb",
         "test_jittered_sampling_default_load_test": "00_core.ipynb",
         "multi_jittered": "00_core.ipynb",
         "test_multi_jittered_with_seed": "00_core.ipynb",
         "test_multi_jittered_default_n": "00_core.ipynb",
         "test_multi_jittered_default_load_test": "00_core.ipynb",
         "is_valid": "00_core.ipynb",
         "poisson_disk": "00_core.ipynb",
         "test_poisson_disk_with_seed": "00_core.ipynb",
         "test_poisson_disk_default_n": "00_core.ipynb",
         "test_poisson_disk_default_load_test": "00_core.ipynb"}

modules = ["core.py",
           "test.py"]

doc_url = "https://ELC.github.io/prosamplers/"

git_url = "https://github.com/ELC/prosamplers/tree/master/"

def custom_doc_links(name): return None
